@@ -2,6 +2,7 @@
 
 # Copyright © 1998 Christian Schwarz and Richard Braakman
 # Copyright © 2020 Felix Lechner
+# Copyright © 2019 Chris Lamb <lamby@debian.org>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -21,8 +22,9 @@
 
 package Lintian::files::contents;
 
-use strict;
+use v5.20;
 use warnings;
+use utf8;
 use autodie;
 
 use List::MoreUtils qw(none);
@@ -126,7 +128,7 @@ sub files {
     return;
 }
 
-sub always {
+sub installable {
     my ($self) = @_;
 
     # get maintainer scripts
