@@ -1,5 +1,6 @@
 # Copyright © 2011 Niels Thykier <niels@thykier.net>
 # Copyright © 2020 Felix Lechner <felix.lechner@lease-up.com>
+# Copyright © 2018 Chris Lamb <lamby@debian.org>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -19,8 +20,9 @@
 
 package Lintian::Profile;
 
-use strict;
+use v5.20;
 use warnings;
+use utf8;
 
 use Carp qw(croak);
 use File::Find::Rule;
@@ -31,7 +33,7 @@ use Path::Tiny;
 use Dpkg::Vendor qw(get_current_vendor get_vendor_info);
 
 use Lintian::Check::Info;
-use Lintian::Deb822Parser qw(read_dpkg_control_utf8);
+use Lintian::Deb822Parser qw(read_dpkg_control);
 use Lintian::Tag::Info;
 
 use constant EMPTY => q{};
@@ -466,7 +468,7 @@ sub _find_profile {
 sub _read_profile {
     my ($self, $path) = @_;
 
-    my @paragraphs = read_dpkg_control_utf8($path, 0);
+    my @paragraphs = read_dpkg_control($path, 0);
 
     for my $paragraph (@paragraphs) {
 
